@@ -640,7 +640,7 @@ def generate_random_correl_matrix(size: int, corr_max: float):
     """
 
      generate_random_correl_matrix:
-     generate a random correlation matrix having an absolute maximum
+     generate a random correlation matrix having an absolute maximum correlation
 
      Parameters
      ----------
@@ -662,17 +662,25 @@ def generate_random_correl_matrix(size: int, corr_max: float):
     return res
 
 
+def generate_vectors_bouquet(vpivot, bouquet_size: int, min_corr: float) -> pd.DataFrame:
+    pass
+
+
 def generate_clusterized_vectors(nclusters: int, nbvect: int, max_inter_corr: float, min_intra_corr: float):
 
     pass
 
 
-def generate_integer_partition(ntot: int, nbpart: int, nmin: int = 1) -> int:
+def generate_integer_partition(ntot: int, nbpart: int, nmin: int = 1):
 
     assert(ntot >= nbpart*nmin)
     rng = np.random.default_rng()
     cuts = np.sort(rng.choice(ntot, nbpart))
-
+    partsize = ntot / nbpart
+    res = [partsize] * nbpart
+    if ntot % nbpart > 0:
+        res[nbpart - 1] = partsize + ntot % nbpart
+    return res
 
 def build_correspondence_map(df_clusters):
 
